@@ -1,4 +1,4 @@
-from .models import Controls
+from models import Controls
 
 
 class BotControlUpdate:
